# XingYun

XingYun is a library that helps backup code, data and log to cloud and manage them. Tastes better if consumed together with [EgorovSystem](https://github.com/FFTYYY/EgorovSystem/tree/main).

## Installation

`pip install xingyun`
